@@ -16,7 +16,7 @@ try:
 except InvalidCacheBackendError:
     raise SkipTest("an appropriate mmongodb backend is not installed")
 
-uri = 'mongodb://localhost/test.beaker'
+uri = 'mongodb://wi:yggdrasil@node0-mongo.webinterpret.com:27017,node1-mongo.webinterpret.com:27017/wiprod.beaker_gridfs_cache'
 
 _mongo = Connection('localhost').test
 
